# ForcedReplicationMethod

A stream will sometimes be forced to use a particular Replication Method. For non-Salesforce sources, this will be a string indicating which replication method is required. Otherwise, it will be an object.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


